@@ -26,7 +26,7 @@ def run_ml_cli_pipeline(args, config_path, ml_cli_template_path):
     if datasets_configuration_json != "" and datasets_configuration_json is not None and datasets_configuration_json is not "-":
         config["datasets"] = json.loads(datasets_configuration_json)
 
-    if mlcli_template_json is None and mlcli_template_json == "" and mlcli_template_json is not "-":
+    if mlcli_template_json is None or mlcli_template_json == "" or mlcli_template_json is not "-":
         with open(ml_cli_template_path) as mlcli_file:
             mlcli_template = mlcli_file.read()
     else:
